@@ -679,6 +679,10 @@ class Dialcentral(object):
 
 	def _on_notebook_switch_page(self, notebook, page, pageIndex):
 		self._reset_tab_refresh()
+
+		didRecentUpdate = False
+		didMessagesUpdate = False
+
 		if pageIndex == self.RECENT_TAB:
 			didRecentUpdate = self._recentViews[self._selectedBackendId].update()
 		elif pageIndex == self.MESSAGES_TAB:
